#
# spec file for package python-spyder-kernels
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# flaky for obs, only test locally
%bcond_with dasktest
Name:           python-spyder-kernels
Version:        3.0.1
Release:        1.2
Summary:        Jupyter kernels for Spyder's console
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/spyder-ide/spyder-kernels
# PyPI tarballs do not include the tests: https://github.com/spyder-ide/spyder-kernels/issues/66
Source0:        https://github.com/spyder-ide/spyder-kernels/archive/v%{version}.tar.gz#/spyder-kernels-%{version}-gh.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module cloudpickle}
BuildRequires:  %{python_module flaky}
BuildRequires:  %{python_module h5py}
BuildRequires:  %{python_module ipykernel >= 6.29.3 with %python-ipykernel < 7}
BuildRequires:  %{python_module ipython >= 8.13 with %python-ipython < 9}
BuildRequires:  %{python_module jupyter_client >= 7.4.9 with %python-jupyter_client < 9}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pydicom}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pyxdg >= 0.26}
BuildRequires:  %{python_module pyzmq >= 24}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module wurlitzer >= 1.0.3}
BuildRequires:  %{python_module xarray}
%if %{with dasktest}
BuildRequires:  %{python_module dask-distributed}
%endif
# /SECTION
Requires:       python-cloudpickle
Requires:       python-pyxdg >= 0.26
Requires:       python-pyzmq >= 24
Requires:       python-wurlitzer >= 1.0.3
Requires:       (python-ipykernel >= 6.29.3 with python-ipykernel < 7)
Requires:       (python-ipython >= 8.13 with python-ipython < 9)
Requires:       (python-jupyter_client >= 7.4.9 with python-jupyter_client < 9)
# gh#spyder-ide/spyder#20789
Provides:       spyder-dicom = 6+%{version}-%{release}
Provides:       spyder-hdf5 = 6+%{version}-%{release}
Obsoletes:      spyder-dicom < 6
Obsoletes:      spyder-hdf5 < 6
BuildArch:      noarch

%python_subpackages

%description
Spyder, the Scientific Python Development Environment, is an
IDE for researchers, engineers and data analysts.

This package provides Jupyter kernels for use with the consoles
of Spyder. These can launched either through Spyder itself or
in an independent Python session, and allow for interactive or
file-based execution of Python code in different environments,
all inside the IDE.

%prep
%autosetup -p1 -n spyder-kernels-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%if ! %{with dasktest}
donttest=("-k" "not test_dask_multiprocessing")
%endif
%pytest "${donttest[@]}"

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE.txt
%{python_sitelib}/spyder_kernels
%{python_sitelib}/spyder_kernels-%{version}.dist-info

%changelog
* Sun Nov 17 2024 Ben Greiner <code@bnavigator.de>
- Update to 3.0.1
  * PR 517: Manually register the Matplotlib inline backend in case
    it hasn't, by @ccordoba12
  * PR 514: Fix development version for the stable branch, by
    @ccordoba12
  * PR 510: Replace Quansight logo by CZI one in Readme, by
    @ccordoba12
  * PR 508: Update workflows to run in the 3.x branch (CI), by
    @ccordoba12
  * PR 506: Make glob and loc kwargs of debug_exec, by @impact27
  * PR 504: Update workflow actions (CI), by @mrclary
  * PR 503: Update load_dicom to accommodate Pydicom 3.0, by
    @mrclary
* Sun Sep  8 2024 Ben Greiner <code@bnavigator.de>
- Update to 3.0.0
  * Speed up debugger execution.
  * Notify Spyder when Matplotlib backend changes.
  * Use control channel for comms instead of a special one.
  * Update variable explorer from the kernel.
  * Simplify kernel configuration from Spyder.
  * Add a comm_handler decorator.
  * Transform runfile, debugfile and runcell commands to IPython
    magics.
  * Add comm handlers to interrupt executions and enter the
    debugger after that.
  * Publish Pdb stack frames to Spyder.
  * Drop support for Python 2 and support Python 3.8+
- Drop spyder-kernels-pr453.patch
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 2.5.2:
  * PR 489 - PR: Fix detecting Matplotlib backend for its 3.9.0
    version
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Skip python39 altogether: no ipykernel anymore
* Sat Mar  2 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.5.1
  * Fix hangs with Maplotlib interactive backends
- Skip testing with xarray on python39
* Fri Nov 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.5.0
  * Add support for chained exceptions to the debugger.
  * Improve getting signatures from docstrings.
  * Restore compatibility with Python 2.
* Thu Aug 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.4.4
  * Increase minimal required version of IPykernel to 6.23.2, by
    @ccordoba12
  * Skip more buggy IPython versions, by @ccordoba12
  * Disable IPython's debugger skip functionality by default, by
    @ccordoba12
  * Remove codecov package and use Github action to upload coverage
    instead, by @ccordoba12 (454)
- Refresh spyder-kernels-pr453.patch
* Wed Jun  7 2023 Ben Greiner <code@bnavigator.de>
- Add spyder-kernels-pr453.patch gh#spyder-ide/spyder-kernels#453
  * fixes test failure with pandas 2
* Thu Apr 27 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.4.3
  * PR 452 - PR: Fix error when executing empty Python script, by
    @rear1019
  * PR 450 - PR: Remove usage of distutils.LooseVersion, by
    @ccordoba12 (440)
  * PR 449 - PR: Add support for Jupyter-client 8, by @ccordoba12
  * PR 448 - PR: Skip IPython versions that give buggy code
    completions, by @ccordoba12
  * PR 434 - PR: Use allow_pickle=True when loading Numpy arrays,
    by @nkleinbaer
  * PR 430 - PR: Inform GUI about position of exception in post
    mortem debugging, by @rear1019
* Sun Mar 19 2023 Ben Greiner <code@bnavigator.de>
- Skip test file requiring xarray on python38
* Thu Jan 19 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.4.2
  * formatargspec is deprecated since Python 3.5
* Fri Dec 30 2022 Ben Greiner <code@bnavigator.de>
- Update to version 2.4.1
  * Make spyder-kernels compatible with IPython 8
* Sun Nov  6 2022 Ben Greiner <code@bnavigator.de>
- Update to verison 2.4.0
  * Add support for Python 3.11
  * Flush standard streams after execution.
* Sun Sep  4 2022 andy great <andythe_great@pm.me>
- Update to version 2.3.3.
  * Use get_size to get variable length for get_var_properties to
    prevent triggering Dask tasks, by @dalthviz
  * Use debugging namespace when curframe is active, by @impact27
    (405)
* Mon Jul 25 2022 Ben Greiner <code@bnavigator.de>
- Update to version 2.3.2
  * Fixed issue 394 - The variable explorer is broken while
  debugging
  * PR 399: Increase minimal required version of jupyter_client to
    7.3.4, by @ccordoba12
  * PR 398: Fix module namespace, by @impact27
  * PR 395: Fix running namespace and improve eventloop integration
    while debugging, by @impact27 (394)
  * PR 389: Fix debug filename path for remote debugging, by
    @impact27 (18330)
  * PR 388: Fix getting args from functions or methods, by
    @ccordoba12
  * PR 386: Fix flaky test, by @impact27
  * PR 381: Eliminate unnecessary updates of the Variable Explorer
    while debugging, by @rear1019
  * PR 378: Append paths that come from Spyder's Python path
    manager to the end of sys.path, by @mrclary
* Tue May 24 2022 Ben Greiner <code@bnavigator.de>
- Update to version 2.3.1
  * Add an upper constraint to our most important dependencies, by
    @ccordoba12
  * Increase minimal required version of jupyter_client to 7.3.1,
    by @ccordoba12
* Sat Apr  9 2022 Ben Greiner <code@bnavigator.de>
- Update to version 2.3.0
  * Add new handler to detect the current Matplotlib interactive
    backend.
  * Increase minimal required version of ipykernel to 6.9.2, by
    @ccordoba12
  * Handle getting dasks objects size, by @dalthviz
  * Add new handler to detect the current Matplotlib interactive
    backend, by @ccordoba12
  * Remove support for outdated and unused Matplotlib backends, by
    @ccordoba12
  * Catch FileNotFoundError when trying to get file code from the
    frontend, by @ccordoba12
  * Increase minimal required IPython version to 7.31.1, by
    @ccordoba12 (344)
  * Avoid modifying the namespace view settings by reference, by
    @impact27 (320)
  * Fix issues when debugging comprehensions, by @impact27 (371)
  * Leave unsaved files in linecache, by @impact27
  * Print last line of Pdb code and some debugger fixes, by
    @impact27 (330)
* Fri Jan 21 2022 Ben Greiner <code@bnavigator.de>
- Update to version 2.2.1
  * Improve error message when setting a Matplotlib backend whose
    module is not present, by @ccordoba12 (347)
  * Filter another benign message coming from comm handlers, by
    @ccordoba12 (365)
  * Catch error when validating if an object is defined in the
    namespace, by @ccordoba12
  * Fix error when running multiprocessing code that contains
    classes, by @impact27
  * Catch KeyError when closing comm, by @ccordoba12
  * Increase minimal required version of pyzmq for Python 3, by
    @ccordoba12
  * Increase minimal required version of ipykernel to 6.6.1, by
    @ccordoba12
  * Require jupyter-client 7.1.0 to fix issues on Windows, by
    @ccordoba12
  * Increase minimal required version of jupyter-client to 7.0+ for
    Python 3, by @ccordoba12
  * Implement a less hacky solution to fix namespace issues, by
    @impact27
  * More namespace fixes, by @impact27
  * Don't print DeprecationWarning's that come from comm handlers,
    by @ccordoba12 (343)
  * Update Quansight logo in Readme, by @ccordoba12
  * Fix some namespace issues, by @impact27 (345)
  * Fix misplaced section in changelog, by @ccordoba12
* Mon Jan 10 2022 Ben Greiner <code@bnavigator.de>
- Skip some tests failing on obs server
* Fri Nov 26 2021 Ben Greiner <code@bnavigator.de>
- Update to version 2.2.0
  * Add the ability to capture segfaults and flush standard streams
    from Spyder.
  * Add support for jupyter_client 7.
- Drop upstreamed spyder-kernels-pr328-unpin_jupyter-client.patch
* Mon Oct 25 2021 Ben Greiner <code@bnavigator.de>
- Unpin jupyter_client<7
  * spyder-kernels-pr328-unpin_jupyter-client.patch
  * gh#spyder-ide/spyder-kernels#328
* Sun Oct 10 2021 Ben Greiner <code@bnavigator.de>
- Update to version 2.1.3
  * Fix errors when setting or getting the Matplotlib backend
  * Prevent other libraries to change the breakpoint builtin
* Thu Sep  2 2021 Ben Greiner <code@bnavigator.de>
- Update to version 2.1.1
  * Avoid runfile to be shadowed by other packages
  * Remove dependency on ipython_genutils
  * Memoize results of is_module_installed
  * Restrict jupyter-client to be less than version 7
* Thu Aug  5 2021 Ben Greiner <code@bnavigator.de>
- Update to version 2.1.0
  * Add support for the Rich and Colorama libraries.
  * Load big modules (e.g. Numpy, Pandas and Scipy) only until it's
    really necessary.
* Mon Jun 14 2021 Ben Greiner <code@bnavigator.de>
- Update to version 2.0.4
  * Support decorator >= 5 (PR 301 by @ccordoba12)
* Fri May 21 2021 Ben Greiner <code@bnavigator.de>
- Update to version 2.0.3
  * PR 291 - PR: Pass adding breakpoint on ValueError,
* Sun May  2 2021 Ben Greiner <code@bnavigator.de>
- Update to version 2.0.2
  * PR 289 - PR: Fix setting tight layout in inline figures
  * PR 287 - PR: Close comm on shutdown
  * PR 282 - PR: Fix numpy.complex deprecation warning in tests
* Thu Apr  8 2021 Ben Greiner <code@bnavigator.de>
- Update to version 2.0.1
  * Color handling in namespace view was moved to Spyder.
  * PR 279 - PR: Add Python types to namespace view
  * PR 285 - PR: Add a new dependency on decorator to fix the
    Cython magic
- Skip python36 flavor entirely
* Mon Feb 22 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.10.2
  * Warn when comm call creates text output, by @impact27
  * Increase minimal required version of ipykernel, by @ccordoba12
  * Better test for non-interactive context, by @juliangilbey
  * Fix assignment detection in exclamation mark mode (Pdb), by
    @impact27
  * Fix recursive debugger, by @impact27
* Mon Feb 15 2021 Ben Greiner <code@bnavigator.de>
- NEP29: python36-numpy in Tumbleweed is no more.
  * don't install numpy and co for testing
  * skip tests requiring them
* Tue Jan 26 2021 Benjamin Greiner <code@bnavigator.de>
- Skip test_dask_multiprocessing as it very often fails on OBS i586
* Sat Dec 19 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.10.1
  Issues Closed
  * Issue 269 - Mark Windows intaller pkgs path as a library to
    prevent reloading modules (PR 270 by @dalthviz)
  * Issue 256 - ImportError: cannot import name
    'leading_empty_lines' (PR 264 by @ccordoba12)
  Pull Requests Merged
  * PR 270 - PR: Treat 'pkgs' path as a library, by @dalthviz (269)
  * PR 267 - PR: Remove handlers that require direct code
    execution, by @ccordoba12
  * PR 266 - PR: Add exception for quit and exit in SpyderPdb,
    by @impact27
  * PR 265 - PR: Add space after dot in a message, by @impact27
  * PR 264 - PR: Add explicit requirement on IPython and require
    version 7.6.0+, by @ccordoba12 (256)
  * PR 263 - PR: Add extra validation to is_module_installed, by
    @ccordoba12
  * PR 262 - PR: Avoid infinite hang when quitting external
    kernels, by @impact27
  * PR 261 - PR: Fix get_cwd permission errors, by @steff456
  * PR 260 - PR: Fix Github actions, by @ccordoba12
- Remove unused mock dependency
* Thu Nov 12 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.10.0
  New features
  * Use '!' to prefix Pdb commands.
  * Show length of all iterables.
  Issues Closed
  * Issue 247 - Remove from warning that future versions of
    Spyder will give an error when using non-Python syntax
    (PR 243 by @impact27)
  * Issue 245 - Display size of string in variable editor
  Pull Requests Merged
  * PR 255 - PR: Fix warning for '!' Pdb option, by @impact27
  * PR 253 - PR: Extend sys.path with paths that come from
    Spyder, by @ccordoba12
  * PR 252 - PR: Use frame locals when evaluating code in
    Pdb, by @impact27
  * PR 251 - PR: Catch errors when trying to get the len of
    an object, by @impact27
  * PR 250 - PR: Show size of objects correctly, if they
    implement len(), by @skjerns
  * PR 246 - PR: Allow sorting with custom sorting key, by
    @skjerns
  * PR 244 - PR: Set multiprocessing ORIGINAL_DIR at startup,
    by @impact27 (13632)
  * PR 243 - PR: Allow leading indents in cells, by
    @impact27 (247)
  * PR 242 - PR: Display error if required, by @impact27
  * PR 240 - PR: Hide runcell and runfile frames using a new
    IPython feature, by @impact27
  * PR 239 - PR: Improve Pdb input handling, by @impact27
  * PR 232 - PR: Make do_where go to the current file, by @impact27
  * PR 223 - PR: Add methods to handle IPython console config on
    the fly, by @dalthviz
  * PR 214 - PR: Use '!' for Pdb commands, by @impact27
* Wed Sep  2 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.9.4
  * PR 238 - PR: Set get_local_scope correctly while debugging,
    by @impact27
  * PR 235 - PR: Set debug state correctly on exception,
    by @impact27
  * PR 233 - PR: Don't save file in runcell, by @impact27
- Version 1.9.3
  * Require dask[distributed] for tests, by @bnavigator (236)
* Fri Jul 10 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.9.2
  * PR gh#spyder-ide/spyder-kernels#234
    Fix a problem caused by ipykernel 5.3.1, by @ccordoba12
  * PR gh#spyder-ide/spyder-kernels#231
    Send comm config on every message, by @impact27
  * PR gh#spyder-ide/spyder-kernels#230
    Send comm config before any wait just to be sure, by @impact27
  * PR gh#spyder-ide/spyder-kernels#229
    Add warning on console if file is not saved, by @impact27
  * PR gh#spyder-ide/spyder-kernels#228
    Fix post_mortem interaction, by @dalthviz
  * PR gh#spyder-ide/spyder-kernels#227
    Create a constant for numeric Numpy types, by @dalthviz
  * PR gh#spyder-ide/spyder-kernels#226
    Backport PR 225, by @ccordoba12
  * PR gh#spyder-ide/spyder-kernels#222
    Remove the current working directory from sys.path for Python 3.7+,
    by @ccordoba12
  * PR gh#spyder-ide/spyder-kernels#220
    Make multithreading patch work for all OSes in Python 3,
    by @steff456 (gh#spyder-ide/spyder#12465)
- use pytest macro
- add scipy and dask-distributed to test requirements
* Thu May  7 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.9.1:
  - Issues Closed:
  - [Issue 217](https://github.com/spyder-ide/spyder-kernels/issues/217) - Maximum recursion depth exceeded ([PR 218](https://github.com/spyder-ide/spyder-kernels/pull/218) by [@ccordoba12](https://github.com/ccordoba12))
  - In this release 1 issue was closed.
  - Pull Requests Merged:
  - [PR 219](https://github.com/spyder-ide/spyder-kernels/pull/219) - PR: Check that startup file exists, by [@impact27](https://github.com/impact27) ([12442](https://github.com/spyder-ide/spyder/issues/12442))
  - [PR 218](https://github.com/spyder-ide/spyder-kernels/pull/218) - PR: Avoid an error when computing the shape of Pandas objects, by [@ccordoba12](https://github.com/ccordoba12) ([217](https://github.com/spyder-ide/spyder-kernels/issues/217))
  - [PR 215](https://github.com/spyder-ide/spyder-kernels/pull/215) - PR: Fix post mortem functionality, by [@impact27](https://github.com/impact27)
  - [PR 212](https://github.com/spyder-ide/spyder-kernels/pull/212) - PR: Set namespace correctly when running in new namespace, by [@impact27](https://github.com/impact27)
  - [PR 211](https://github.com/spyder-ide/spyder-kernels/pull/211) - PR: Use Exception instead of ImportError in is_special_kernel_valid, by [@ccordoba12](https://github.com/ccordoba12)
  - In this release 5 pull requests were closed.
* Mon Apr 20 2020 Benjamin Greiner <code@bnavigator.de>
- remove unused python2 requirements
* Sun Mar 22 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove fix-tests-ipython-7.10.patch, already included upstream
* Sun Mar 15 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.9.0:
  - New features:
  - Allow IPython magics in code again.
  - Allow PyQt applications to be run multiple times.
  - Remove `__file__` after running a file.
  - Pull Requests Merged:
  - [PR 209](https://github.com/spyder-ide/spyder-kernels/pull/209) - PR: Improve message about using invalid syntax in cells and files, by [@ccordoba12](https://github.com/ccordoba12)
  - [PR 208](https://github.com/spyder-ide/spyder-kernels/pull/208) - PR: Add flag to override data and handle NpzFile instances, by [@dalthviz](https://github.com/dalthviz)
  - [PR 206](https://github.com/spyder-ide/spyder-kernels/pull/206) - PR: Move CI to github actions on branch 1.x, by [@goanpeca](https://github.com/goanpeca)
  - [PR 204](https://github.com/spyder-ide/spyder-kernels/pull/204) - PR: Remove load_exception in CommBase, by [@impact27](https://github.com/impact27)
  - [PR 200](https://github.com/spyder-ide/spyder-kernels/pull/200) - PR: Fix %%varexp namespace, by [@impact27](https://github.com/impact27) ([6695](https://github.com/spyder-ide/spyder/issues/6695))
  - [PR 199](https://github.com/spyder-ide/spyder-kernels/pull/199) - PR: Prevent completion from changing local objects while debugging, by [@impact27](https://github.com/impact27)
  - [PR 198](https://github.com/spyder-ide/spyder-kernels/pull/198) - PR: Add method to check dependencies for special consoles, by [@dalthviz](https://github.com/dalthviz)
  - [PR 195](https://github.com/spyder-ide/spyder-kernels/pull/195) - PR: Give access to the running namespace when refreshing variables, by [@impact27](https://github.com/impact27)
  - [PR 193](https://github.com/spyder-ide/spyder-kernels/pull/193) - PR: Update test to work with IPython 7.10+, by [@impact27](https://github.com/impact27)
  - [PR 192](https://github.com/spyder-ide/spyder-kernels/pull/192) - PR: Resend comm configuration on timeout, by [@impact27](https://github.com/impact27)
  - [PR 190](https://github.com/spyder-ide/spyder-kernels/pull/190) - PR: Allow IPython magics in code again, by [@impact27](https://github.com/impact27) ([11023](https://github.com/spyder-ide/spyder/issues/11023))
  - [PR 189](https://github.com/spyder-ide/spyder-kernels/pull/189) - PR: Patch PyQt to save created QApplication instances, by [@impact27](https://github.com/impact27) ([2970](https://github.com/spyder-ide/spyder/issues/2970))
  - [PR 187](https://github.com/spyder-ide/spyder-kernels/pull/187) - PR: Remove `__file__` after running script, by [@impact27](https://github.com/impact27) ([1918](https://github.com/spyder-ide/spyder/issues/1918))
  - In this release 13 pull requests were closed.
* Sat Feb  1 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- add fix-tests-ipython-7.10.patch to fix compatibility with IPython > 7.10
* Sat Jan 25 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove fix-tests-pandas.patch, merged upstream
- update to version 1.8.1:
  - Pull Requests Merged:
  - [PR 185](https://github.com/spyder-ide/spyder-kernels/pull/185) - PR: Process first frame in Pdb
  - In this release 1 pull request was closed.
- update to version 1.8.0:
  - New features:
  - Add an option to exclude callables and modules in namespace view.
  - Add methods to update `sys.path` from Spyder.
  - Add an option to execute IPython events in Pdb.
  - Pull Requests Merged:
  - [PR 183](https://github.com/spyder-ide/spyder-kernels/pull/183) - PR: Add an option to namespace view settings to exclude callables and modules
  - [PR 182](https://github.com/spyder-ide/spyder-kernels/pull/182) - PR: Use IPython completer for Pdb
  - [PR 181](https://github.com/spyder-ide/spyder-kernels/pull/181) - PR: Add path update methods
  - [PR 180](https://github.com/spyder-ide/spyder-kernels/pull/180) - PR: Cleanup spydercustomize
  - [PR 179](https://github.com/spyder-ide/spyder-kernels/pull/179) - PR: Use a timeout in CommBase if a call passes one different from None
  - [PR 178](https://github.com/spyder-ide/spyder-kernels/pull/178) - PR: Correctly set namespace while debugging
  - [PR 175](https://github.com/spyder-ide/spyder-kernels/pull/175) - PR: Add an option to execute IPython events in Pdb
  - [PR 174](https://github.com/spyder-ide/spyder-kernels/pull/174) - PR: Prevent pdb syntax error from blocking the console ([10588](https://github.com/spyder-ide/spyder/issues/10588))
  - In this release 8 pull requests were closed.
- update to version 1.7.0:
  - New features:
  - Create a new ZMQ socket for comms.
  - Allow different frontends to have different pickle
    protocols.
  - Add a way to ignore installed Python libraries while
    debugging
  - Pull Requests Merged:
  - [PR 177](https://github.com/spyder-ide/spyder-kernels/pull/177) - PR: Update ipykernel required version ([2902](https://github.com/spyder-ide/spyder/issues/2902))
  - [PR 176](https://github.com/spyder-ide/spyder-kernels/pull/176) - PR: Improve displayed type and value for generic objects
  - [PR 169](https://github.com/spyder-ide/spyder-kernels/pull/169) - PR: Create a Comm socket
  - [PR 168](https://github.com/spyder-ide/spyder-kernels/pull/168) - PR: Require more recent version of jupyter-client
  - [PR 167](https://github.com/spyder-ide/spyder-kernels/pull/167) - PR: Don't demand that a file exists in Pdb
  - [PR 166](https://github.com/spyder-ide/spyder-kernels/pull/166) - PR: Allow different frontends to have different pickle protocols
  - [PR 152](https://github.com/spyder-ide/spyder-kernels/pull/152) - PR: Add a way to ignore installed Python libraries while debugging
  - In this release 7 pull requests were closed.
- update to version 1.6.0:
  - New features:
  - Allow IPython magics in Pdb.
  - Allow Pdb to run multiline statments.
  - Make `runfile` to retrieve code from Spyder.
  - Add code completion to Pdb.
  - Issues Closed:
  - [Issue 139](https://github.com/spyder-ide/spyder-kernels/issues/139) - Regression: runfile doesn't execute ipython magic ([PR 143](https://github.com/spyder-ide/spyder-kernels/pull/143))
  - In this release 1 issue was closed.
  - Pull Requests Merged:
  - [PR 163](https://github.com/spyder-ide/spyder-kernels/pull/163) - PR: Fix tests that use setup_kernel
  - [PR 162](https://github.com/spyder-ide/spyder-kernels/pull/162) - PR: Improve Pdb sigint handler
  - [PR 161](https://github.com/spyder-ide/spyder-kernels/pull/161) - PR: Fix post-mortem debugging
  - [PR 157](https://github.com/spyder-ide/spyder-kernels/pull/157) - PR: Fix breakpoint update ([10290](https://github.com/spyder-ide/spyder/issues/10290))
  - [PR 154](https://github.com/spyder-ide/spyder-kernels/pull/154) - PR: Allow IPython magics in Pdb
  - [PR 153](https://github.com/spyder-ide/spyder-kernels/pull/153) - PR: Add a setting to disable printing the stack on every Pdb command
  - [PR 151](https://github.com/spyder-ide/spyder-kernels/pull/151) - PR: Remove Pdb Monkeypatching
  - [PR 148](https://github.com/spyder-ide/spyder-kernels/pull/148) - PR: Allow Pdb to run multiline statments
  - [PR 143](https://github.com/spyder-ide/spyder-kernels/pull/143) - PR: Make runfile to retrieve code from the Spyder editor and add it to linecache ([1643](https://github.com/spyder-ide/spyder/issues/1643), [139](https://github.com/spyder-ide/spyder-kernels/issues/139))
  - [PR 133](https://github.com/spyder-ide/spyder-kernels/pull/133) - PR: Add code completion to Pdb
  - In this release 10 pull requests were closed.
- update to version 1.5.0:
  - New features:
  - Add a new debugcell builtin command.
  - Make runfile work in an empty namespace by default.
  - Improve the display of tracebacks.
  - Use the highest pickle protocol available to serialize data.
  - Use Jupyter comms to communicate with the Spyder frontend.
  - This release also contains all fixes present in versions 0.5.1
    and 0.5.2.
  - Issues Closed:
  - [Issue 147](https://github.com/spyder-ide/spyder-kernels/issues/147) - debugfile() got an unexpected keyword argument 'current_namespace' ([PR 150](https://github.com/spyder-ide/spyder-kernels/pull/150))
  - [Issue 145](https://github.com/spyder-ide/spyder-kernels/issues/145) - KeyError on comms when restarting the kernel ([PR 146](https://github.com/spyder-ide/spyder-kernels/pull/146))
  - [Issue 97](https://github.com/spyder-ide/spyder-kernels/issues/97) - Can't repeat runcell from terminal ([PR 112](https://github.com/spyder-ide/spyder-kernels/pull/112))
  - [Issue 73](https://github.com/spyder-ide/spyder-kernels/issues/73) - Select a higher Pickle protocol in case Spyder and the kernel are running in Python 3.4+ ([PR 111](https://github.com/spyder-ide/spyder-kernels/pull/111))
  - In this release 4 issues were closed.
  - Pull Requests Merged:
  - [PR 150](https://github.com/spyder-ide/spyder-kernels/pull/150) - PR: Add current_namespace kwarg to debugfile ([147](https://github.com/spyder-ide/spyder-kernels/issues/147))
  - [PR 146](https://github.com/spyder-ide/spyder-kernels/pull/146) - PR: Set closed flag before deleting comms  ([145](https://github.com/spyder-ide/spyder-kernels/issues/145))
  - [PR 144](https://github.com/spyder-ide/spyder-kernels/pull/144) - PR: Solve error with exit command not being defined in the debugger
  - [PR 142](https://github.com/spyder-ide/spyder-kernels/pull/142) - PR: Set debug state before asking for input
  - [PR 140](https://github.com/spyder-ide/spyder-kernels/pull/140) - PR: Update jupyter-client minimal required version
  - [PR 137](https://github.com/spyder-ide/spyder-kernels/pull/137) - PR: Add a way to change foreground color of Sympy repr's
  - [PR 136](https://github.com/spyder-ide/spyder-kernels/pull/136) - PR: Ask the frontend to save files before running them
  - [PR 134](https://github.com/spyder-ide/spyder-kernels/pull/134) - PR: Improve the display of tracebacks and better handle namespace and __file__ during execution
  - [PR 131](https://github.com/spyder-ide/spyder-kernels/pull/131) - PR: Make runfile work in an empty namespace
  - [PR 130](https://github.com/spyder-ide/spyder-kernels/pull/130) - PR: Add .pickle files to .gitignore
  - [PR 128](https://github.com/spyder-ide/spyder-kernels/pull/128) - PR: Fix deprecated import
  - [PR 112](https://github.com/spyder-ide/spyder-kernels/pull/112) - PR: Use the comms API to improve runcell and add a new debugcell command ([97](https://github.com/spyder-ide/spyder-kernels/issues/97))
  - [PR 111](https://github.com/spyder-ide/spyder-kernels/pull/111) - PR: Use Jupyter comms to communicate with the Spyder frontend ([73](https://github.com/spyder-ide/spyder-kernels/issues/73))
  - In this release 13 pull requests were closed.
- update to version 1.4.0:
  - New features:
  - Add entries necessary for the new Object Explorer to
    REMOTE_SETTINGS.
  - This release also contains all features and fixes present in
    version 0.5.0
  - Pull Requests Merged:
  - [PR 100](https://github.com/spyder-ide/spyder-kernels/pull/100) - PR: Add object explorer settings to REMOTE_SETTINGS
  - In this release 1 pull request was closed.
- update to version 1.3.3:
  - New features:
  - This release contains all features and fixes present in versions
    0.4.3 and 0.4.4
  - Issues Closed:
  - [Issue 93](https://github.com/spyder-ide/spyder-kernels/issues/93) - test_np_threshold is failing ([PR 95](https://github.com/spyder-ide/spyder-kernels/pull/95))
  - In this release 1 issue was closed.
  - Pull Requests Merged:
  - [PR 95](https://github.com/spyder-ide/spyder-kernels/pull/95) - PR: Change np.nan for np.inf in test_np_threshold ([93](https://github.com/spyder-ide/spyder-kernels/issues/93))
  - In this release 1 pull request was closed.
- update to version 1.3.2:
  - Sister release for 0.4.2
- update to version 1.3.1:
  - Sister release for 0.4.1
- update to version 1.3.0:
  - New features:
  - Make runcell set __file__ to the path of the file containing the cell
  - This release also contains all features and fixes present in version
    0.4.
  - Issues Closed:
  - [Issue 78](https://github.com/spyder-ide/spyder-kernels/issues/78) - Nopython jit of numba is not working in runcell ([PR 79](https://github.com/spyder-ide/spyder-kernels/pull/79))
  - [Issue 76](https://github.com/spyder-ide/spyder-kernels/issues/76) - Detect the name of the file currently running the cell ([PR 77](https://github.com/spyder-ide/spyder-kernels/pull/77))
  - In this release 2 issues were closed.
  - Pull Requests Merged:
  - [PR 79](https://github.com/spyder-ide/spyder-kernels/pull/79) - PR: Remove user module reloader from runcell ([78](https://github.com/spyder-ide/spyder-kernels/issues/78))
  - [PR 77](https://github.com/spyder-ide/spyder-kernels/pull/77) - PR: Have runcell set __file__ to the path of the file containing the cell  ([76](https://github.com/spyder-ide/spyder-kernels/issues/76))
  - [PR 72](https://github.com/spyder-ide/spyder-kernels/pull/72) - PR: Fix numpy printoptions format ([7885](https://github.com/spyder-ide/spyder/issues/7885))
  - In this release 3 pull requests were closed.
- update to version 1.2:
  - New features:
  - Add the `runcell` command to run cells from Spyder's editor
    without pasting their contents in the console.
  - This release also contains all features and fixes present in
    version 0.3.
  - Issues Closed:
  - [Issue 57](https://github.com/spyder-ide/spyder-kernels/issues/57) - Add a test for runcell ([PR 70](https://github.com/spyder-ide/spyder-kernels/pull/70))
  - In this release 1 issue was closed.
  - Pull Requests Merged:
  - [PR 70](https://github.com/spyder-ide/spyder-kernels/pull/70) - PR: Add a test for the runcell command ([57](https://github.com/spyder-ide/spyder-kernels/issues/57))
  - [PR 69](https://github.com/spyder-ide/spyder-kernels/pull/69) - PR: Start testing in macOS
  - [PR 67](https://github.com/spyder-ide/spyder-kernels/pull/67) - PR: Drop using ci-helpers in our CIs
  - [PR 58](https://github.com/spyder-ide/spyder-kernels/pull/58) - PR: runcell trigger post_execute before run_cell to end the run_cell pre_execute
  - [PR 7](https://github.com/spyder-ide/spyder-kernels/pull/7) - PR: Add runcell to spydercustomize
  - In this release 5 pull requests were closed.
- update to version 1.1:
  - Issues Closed:
  - [Issue 14](https://github.com/spyder-ide/spyder-kernels/issues/14) - Startup lines to split with semicolon instead of comma ([PR 15](https://github.com/spyder-ide/spyder-kernels/pull/15))
  - In this release 1 issue was closed.
  - Pull Requests Merged:
  - [PR 15](https://github.com/spyder-ide/spyder-kernels/pull/15) - PR: Separate startup run_lines with semicolon instead of comma ([14](https://github.com/spyder-ide/spyder-kernels/issues/14))
  - In this release 1 pull request was closed.
- update to version 1.0.3:
  - Sister release for 0.2.6
- update to version 1.0.2:
  - Sister release for 0.2.5
- update to version 1.0.1:
  - Sister release for 0.2.4
- update to version 1.0.0:
  - Initial release for Spyder 4
- update to version 0.5.2:
  - Issues Closed:
  - [Issue 132](https://github.com/spyder-ide/spyder-kernels/issues/132) - tests use removed pandas.Panel ([PR 135](https://github.com/spyder-ide/spyder-kernels/pull/135))
  - In this release 1 issue was closed.
  - Pull Requests Merged:
  - [PR 149](https://github.com/spyder-ide/spyder-kernels/pull/149) - PR: Add xarray to our test deps in setup.py
  - [PR 135](https://github.com/spyder-ide/spyder-kernels/pull/135) - PR: Replace usage of Pandas Panel for Xarray Dataset in our tests ([132](https://github.com/spyder-ide/spyder-kernels/issues/132))
  - In this release 2 pull requests were closed.
* Sat Nov 30 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Add new testing dependency python*-flaky to fix tests and build.
* Tue Aug  6 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Add fix-tests-pandas.patch and remove workaround to fix tests.
* Mon Jul 29 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Do not build for Python2 anymore as dependencies like numpy are not provided for Python 2 too.
- Skip a test relying on an old version of pandas.
* Mon Jul 15 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.5.1:
  - Issues Closed:
  - [Issue 121](https://github.com/spyder-ide/spyder-kernels/issues/121) - Add test requirements to setup.py ([PR 122](https://github.com/spyder-ide/spyder-kernels/pull/122))
  - [Issue 120](https://github.com/spyder-ide/spyder-kernels/issues/120) - Backport CI configuration from master to 0.x ([PR 123](https://github.com/spyder-ide/spyder-kernels/pull/123))
  - In this release 2 issues were closed.
  - Pull Requests Merged:
  - [PR 125](https://github.com/spyder-ide/spyder-kernels/pull/125) - PR: Fix not including tests in tarballs and wheels
  - [PR 123](https://github.com/spyder-ide/spyder-kernels/pull/123) - PR: Backport CI configuration from master to 0.x ([120](https://github.com/spyder-ide/spyder-kernels/issues/120))
  - [PR 122](https://github.com/spyder-ide/spyder-kernels/pull/122) - PR: Add tests requirements to setup.py ([121](https://github.com/spyder-ide/spyder-kernels/issues/121))
  - In this release 3 pull requests were closed.
* Sun Jun 30 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.5.0:
  - New features:
  - Set Matplotlib backend to inline for kernels started in a terminal.
  - Handle option sent from Spyder to show/hide cmd windows generated
    by the subprocess module.
  - Issues Closed:
  - [Issue 108](https://github.com/spyder-ide/spyder-kernels/issues/108) - Set matplotlib backend to inline by default on starting a new kernel ([PR 110](https://github.com/spyder-ide/spyder-kernels/pull/110))
  - In this release 1 issue was closed.
  - Pull Requests Merged:
  - [PR 110](https://github.com/spyder-ide/spyder-kernels/pull/110) - PR: Set Matplotlib backend to inline for kernels started outside Spyder ([108](https://github.com/spyder-ide/spyder-kernels/issues/108))
  - [PR 107](https://github.com/spyder-ide/spyder-kernels/pull/107) - PR: Use Readme.md for long description in PyPi
  - [PR 104](https://github.com/spyder-ide/spyder-kernels/pull/104) - PR: Handle option to show/hide cmd windows generated by the subprocess module
  - In this release 3 pull requests were closed.
- remove 818a6b5f619ef917f4c3413c9522212cd9b2fdfd.patch, included upstream
* Mon Jun  3 2019 Todd R <toddrme2178@gmail.com>
- Fix jupyter dependencies.
* Sun Jun  2 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- actually remove the unneeded patches
- add 818a6b5f619ef917f4c3413c9522212cd9b2fdfd.patch for a numpy change
* Sat May  4 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove make-tk-optional.patch, included already
- remove make-turtle-optional.patch, included already
- update to version 0.4.4:
  * Issues Closed
  * Issue 102 - Tkinter is now required for version 0.4.3 after patching the turtle code (PR 103)
  * Pull Requests Merged
  * PR 106 - PR: Skip test_turtle_launch if Tk is not installed
  * PR 103 - PR: Enclose turtle customizations in a try/except to avoid a dependency on Tk (102)
* Sun Apr  7 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- add make-tk-optional.patch
- add make-turtle-optional.patch
- update to version 0.4.3:
  - Issues closed:
  - [Issue 91](https://github.com/spyder-ide/spyder-kernels/issues/91) - KeyError when running "%%reset -f" programmatically ([PR 96](https://github.com/spyder-ide/spyder-kernels/pull/96))
  - Pull Requests Merged:
  - [PR 96](https://github.com/spyder-ide/spyder-kernels/pull/96) - PR:  Avoid error when trying to pop __file__ out of the current namespace ([91](https://github.com/spyder-ide/spyder-kernels/issues/91))
  - [PR 92](https://github.com/spyder-ide/spyder-kernels/pull/92) - PR: Include user site-packages directory in the list of excluded paths by the UMR ([8776](https://github.com/spyder-ide/spyder/issues/8776))
  - [PR 90](https://github.com/spyder-ide/spyder-kernels/pull/90) - PR: Patch turtle.bye to make it work with multiple runnings of the same code ([6278](https://github.com/spyder-ide/spyder/issues/6278))
- update to version 0.4.2:
  - Issues closed:
  - [Issue 85](https://github.com/spyder-ide/spyder-kernels/issues/85) - NameError: name 'modpath' is not defined ([PR 86](https://github.com/spyder-ide/spyder-kernels/pull/86))
  - Pull Requests Merged:
  - [PR 88](https://github.com/spyder-ide/spyder-kernels/pull/88) - PR: Improve Cython activation
  - [PR 87](https://github.com/spyder-ide/spyder-kernels/pull/87) - PR: Fix running Cython files
  - [PR 86](https://github.com/spyder-ide/spyder-kernels/pull/86) - PR: Fix problems with UMR's run method ([85](https://github.com/spyder-ide/spyder-kernels/issues/85))
- update to version 0.4.1:
  - Pull Requests Merged:
  - [PR 84](https://github.com/spyder-ide/spyder-kernels/pull/84) - PR: Better way to skip standard library and site-packages modules from UMR
  - [PR 83](https://github.com/spyder-ide/spyder-kernels/pull/83) - PR: Blacklist tensorflow from the UMR ([8697](https://github.com/spyder-ide/spyder/issues/8697))
- update to version 0.4:
  - New features:
  - This release fixes several important issues that prevented
    saving the current namespace to work as expected.
  - Issues closed:
  - [Issue 75](https://github.com/spyder-ide/spyder-kernels/issues/75) - Namespace serialization silently fails if any object is unserializable, e.g. a Python module ([PR 81](https://github.com/spyder-ide/spyder-kernels/pull/81))
  - [Issue 9](https://github.com/spyder-ide/spyder-kernels/issues/9) - Spydata files won't import if the original filename is changed ([PR 80](https://github.com/spyder-ide/spyder-kernels/pull/80))
  - Pull Requests Merged:
  - [PR 82](https://github.com/spyder-ide/spyder-kernels/pull/82) - PR: Enclose calls to load wurlitzer and autoreload in try/except's ([8668](https://github.com/spyder-ide/spyder/issues/8668))
  - [PR 81](https://github.com/spyder-ide/spyder-kernels/pull/81) - PR: Fix and improve saving of Spyder namespace with many types of objects ([75](https://github.com/spyder-ide/spyder-kernels/issues/75))
  - [PR 80](https://github.com/spyder-ide/spyder-kernels/pull/80) - PR: Fix loading Spydata file with changed filename and other edge-cases in load_dict ([9](https://github.com/spyder-ide/spyder-kernels/issues/9))
- update to version 0.3:
  - New features:
  - Add Wurlitzer as a new dependency on Posix systems.
  - Add tests for the console kernel.
  - Issues closed:
  - [Issue 62](https://github.com/spyder-ide/spyder-kernels/issues/62) - Add support for AppVeyor ([PR 63](https://github.com/spyder-ide/spyder-kernels/pull/63))
  - [Issue 60](https://github.com/spyder-ide/spyder-kernels/issues/60) - Only load Wurlitzer in Posix systems ([PR 64](https://github.com/spyder-ide/spyder-kernels/pull/64))
  - [Issue 23](https://github.com/spyder-ide/spyder-kernels/issues/23) - Add tests for the console kernel ([PR 37](https://github.com/spyder-ide/spyder-kernels/pull/37))
  - Pull Requests Merged:
  - [PR 64](https://github.com/spyder-ide/spyder-kernels/pull/64) - PR: Don't load Wurlitzer extension on Windows because it has no effect there ([60](https://github.com/spyder-ide/spyder-kernels/issues/60))
  - [PR 63](https://github.com/spyder-ide/spyder-kernels/pull/63) - PR: Test on Windows with Appveyor ([62](https://github.com/spyder-ide/spyder-kernels/issues/62))
  - [PR 61](https://github.com/spyder-ide/spyder-kernels/pull/61) - PR: Patch multiprocessing to make it work when all variables are removed ([8128](https://github.com/spyder-ide/spyder/issues/8128))
  - [PR 59](https://github.com/spyder-ide/spyder-kernels/pull/59) - PR: Filter deprecation warnings in ipykernel ([8103](https://github.com/spyder-ide/spyder/issues/8103))
  - [PR 56](https://github.com/spyder-ide/spyder-kernels/pull/56) - PR: Add Wurlitzer to Readme
  - [PR 55](https://github.com/spyder-ide/spyder-kernels/pull/55) - PR: Exclude all tests from our tarballs
  - [PR 54](https://github.com/spyder-ide/spyder-kernels/pull/54) - PR: Add the Wurlitzer package to capture stdout/stderr from C libraries ([3777](https://github.com/spyder-ide/spyder/issues/3777))
  - [PR 53](https://github.com/spyder-ide/spyder-kernels/pull/53) - PR: Remove current working directory from sys.path before starting the console kernel ([8007](https://github.com/spyder-ide/spyder/issues/8007))
  - [PR 37](https://github.com/spyder-ide/spyder-kernels/pull/37) - PR: Initial tests for the console kernel ([23](https://github.com/spyder-ide/spyder-kernels/issues/23))
  - [PR 36](https://github.com/spyder-ide/spyder-kernels/pull/36) - PR: Make tests to really fail in CircleCI
  - [PR 21](https://github.com/spyder-ide/spyder-kernels/pull/21) - PR: Add AUTHORS.txt in MANIFEST.in to include in package
* Tue Sep 11 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
- downgrade to version 0.2.6 (boo#1105801).
* Thu Aug 16 2018 jengelh@inai.de
- Trim redundancies from description.
* Mon Aug 13 2018 toddrme2178@gmail.com
- Initial version
